@@ -323,14 +323,14 @@ int main(int argc, char *argv[])
   int                       optChar;
   vector<string>            hosts = {
     "ria",    "www",   "kiva", "grover", "lassie", "nomnom", "pi4e",
-    "snoopy", "spark", "thrip"
+    "snoopy", "spark", "thrip", "toto"
   };
   vector<McTally::Request>  requests = {
     McTally::Request(McTally::e_uname),
     McTally::Request(McTally::e_uptime),
     McTally::Request(McTally::e_loadAverages),
     McTally::Request(McTally::e_logins),
-    McTally::Request("net.mcplex.*|mcblock|mcloc|mcrover|mctally"
+    McTally::Request("net.mcplex.*|mcblock|mcloc|mcrover|mctally|Mcweather"
                      "|DwmDns|libDwm.*")
   };
   
